bayespy.inference.vmp.nodes.gamma.GammaDistribution.plates_from_parent
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaDistribution.plates_from_parent